# Builder classes

## Builders

🤗 Datasets relies on two main classes during the dataset building process: [`DatasetBuilder`] and [`BuilderConfig`].

[[autodoc]] datasets.DatasetBuilder

[[autodoc]] datasets.GeneratorBasedBuilder

[[autodoc]] datasets.BeamBasedBuilder

[[autodoc]] datasets.ArrowBasedBuilder

[[autodoc]] datasets.BuilderConfig

## Download

[[autodoc]] datasets.DownloadManager

[[autodoc]] datasets.StreamingDownloadManager

[[autodoc]] datasets.DownloadConfig

[[autodoc]] datasets.DownloadMode

## Splits

[[autodoc]] datasets.SplitGenerator

[[autodoc]] datasets.Split

[[autodoc]] datasets.NamedSplit

[[autodoc]] datasets.NamedSplitAll

[[autodoc]] datasets.ReadInstruction

## Version

[[autodoc]] datasets.utils.Version
